@@ -5,10 +5,10 @@ from chargebee import APIError
 
 class Quote(Model):
     class LineItem(Model):
-      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "amount", "pricing_model", "is_taxed", "tax_amount", "tax_rate", "unit_amount_in_decimal", "quantity_in_decimal", "amount_in_decimal", "discount_amount", "item_level_discount_amount", "reference_line_item_id", "description", "entity_description", "entity_type", "tax_exempt_reason", "entity_id", "customer_id"]
+      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "amount", "pricing_model", "is_taxed", "tax_amount", "tax_rate", "unit_amount_in_decimal", "quantity_in_decimal", "amount_in_decimal", "discount_amount", "item_level_discount_amount", "description", "entity_description", "entity_type", "tax_exempt_reason", "entity_id", "customer_id"]
       pass
     class Discount(Model):
-      fields = ["amount", "description", "entity_type", "entity_id", "coupon_set_code"]
+      fields = ["amount", "description", "entity_type", "entity_id"]
       pass
     class LineItemDiscount(Model):
       fields = ["line_item_id", "discount_type", "coupon_id", "entity_id", "discount_amount"]
@@ -23,7 +23,7 @@ class Quote(Model):
       fields = ["line_item_id", "starting_unit", "ending_unit", "quantity_used", "unit_amount", "starting_unit_in_decimal", "ending_unit_in_decimal", "quantity_used_in_decimal", "unit_amount_in_decimal"]
       pass
     class ShippingAddress(Model):
-      fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status", "index"]
+      fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status"]
       pass
     class BillingAddress(Model):
       fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status"]
@@ -34,7 +34,7 @@ class Quote(Model):
     "sub_total", "total", "credits_applied", "amount_paid", "amount_due", "version", "resource_version", \
     "updated_at", "vat_number_prefix", "line_items", "discounts", "line_item_discounts", "taxes", \
     "line_item_taxes", "line_item_tiers", "currency_code", "notes", "shipping_address", "billing_address", \
-    "contract_term_start", "contract_term_end", "contract_term_termination_fee", "business_entity_id"]
+    "contract_term_start", "contract_term_end", "contract_term_termination_fee"]
 
 
     @staticmethod
